@@ -267,7 +267,7 @@ class EmailMessanger:
             print(response['MessageId'])
 
 
-class SlackMessenger:
+class SlackMessanger:
     def __init__(self, service_name: str, block_name: str, slack_token: str, slack_channel_private: str, slack_channel_public: str):
         self.service_name = service_name
         self.block_name = block_name
@@ -338,7 +338,7 @@ def to_sns(message):
 
 
 def post_message_to_slack(plot_name, message, cw_link):
-    slack_m = SlackMessenger()
+    slack_m = SlackMessanger()
     slack_m.to_slack("hi")
 
     # to_sns(message)
@@ -346,7 +346,7 @@ def post_message_to_slack(plot_name, message, cw_link):
 
 if __name__ == '__main__':
     settings.init()
-    slack_m = SlackMessenger("TEST1234")
+    slack_m = SlackMessanger("TEST1234")
 
     slack_m.to_slack("Error in STAGE_EXAMPLE123_DEEP\n"
                      "\n"
